@@ -25,6 +25,7 @@
 #include "preview.h"
 #include "scoreframe.h"
 
+#include <games-gconf.h>
 #include <gdk/gdkkeysyms.h>
 #include <config.h>
 #include <dirent.h>
@@ -120,8 +121,11 @@ Tetris::Tetris(int cmdlLevel):
 
 	/* init gconf */
 	gconf_client = gconf_client_get_default ();
+	if (!games_gconf_sanity_check_string (gconf_client, "")) {
+		exit(1);
+	}
 	gconf_client_add_dir (gconf_client_get_default (), "/apps/gnometris/options", GCONF_CLIENT_PRELOAD_NONE, NULL);
-        gconf_client_notify_add (gconf_client_get_default (), "/apps/gnometris/options", gconfNotify, this, NULL, NULL);
+	gconf_client_notify_add (gconf_client_get_default (), "/apps/gnometris/options", gconfNotify, this, NULL, NULL);
 
 	initOptions ();
 
@@ -535,7 +539,7 @@ Tetris::gameProperties(GtkWidget *widget, void *d)
 		gtk_dialog_new_with_buttons(_("Gnometris preferences"), 
 					    GTK_WINDOW (t->w),
 					    (GtkDialogFlags)0,
-					    GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+					    GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					    NULL);
 
 	gtk_container_set_border_width(GTK_CONTAINER(t->setupdialog), 10);
@@ -1004,7 +1008,7 @@ Tetris::gameAbout(GtkWidget *widget, void *d)
 	}
 
 	about = gnome_about_new("Gnometris", 
-				TETRIS_VERSION, 
+				VERSION, 
 				"(C) 2000 J. Marcin Gorycki",
 				_("Written for my wife, Matylda\n"
 				  "Send comments and bug reports to: "
@@ -1013,7 +1017,10 @@ Tetris::gameAbout(GtkWidget *widget, void *d)
 				(const char **)documenters,
 				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				pixbuf);
-
+	
+	if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
+	
 	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (t->getWidget()));
 	g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
 	gtk_widget_show(about);
